==> zio-aws-iot_2.12-5.17.191.2-sources.jar: zio/aws/iot/model/TransferCertificateResponse.scala <==
package zio.aws.iot.model
import zio.ZIO
import zio.aws.iot.model.primitives.CertificateArn
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class TransferCertificateResponse(
    transferredCertificateArn: Optional[CertificateArn] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot.model.TransferCertificateResponse = {
    import TransferCertificateResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot.model.TransferCertificateResponse
      .builder()
      .optionallyWith(
        transferredCertificateArn.map(value =>
          CertificateArn.unwrap(value): java.lang.String
        )
      )(_.transferredCertificateArn)
      .build()
  }
  def asReadOnly: zio.aws.iot.model.TransferCertificateResponse.ReadOnly =
    zio.aws.iot.model.TransferCertificateResponse.wrap(buildAwsValue())
}
object TransferCertificateResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot.model.TransferCertificateResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot.model.TransferCertificateResponse =
      zio.aws.iot.model.TransferCertificateResponse(
        transferredCertificateArn.map(value => value)
      )
    def transferredCertificateArn: Optional[CertificateArn]
    def getTransferredCertificateArn: ZIO[Any, AwsError, CertificateArn] =
      AwsError.unwrapOptionField(
        "transferredCertificateArn",
        transferredCertificateArn
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot.model.TransferCertificateResponse
  ) extends zio.aws.iot.model.TransferCertificateResponse.ReadOnly {
    override val transferredCertificateArn: Optional[CertificateArn] =
      zio.aws.core.internal
        .optionalFromNullable(impl.transferredCertificateArn())
        .map(value => zio.aws.iot.model.primitives.CertificateArn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot.model.TransferCertificateResponse
  ): zio.aws.iot.model.TransferCertificateResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-iot_3-5.17.148.1-sources.jar: zio/aws/iot/model/TransferCertificateResponse.scala <==
package zio.aws.iot.model
import zio.ZIO
import zio.aws.iot.model.primitives.CertificateArn
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class TransferCertificateResponse(
    transferredCertificateArn: Option[CertificateArn] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot.model.TransferCertificateResponse = {
    import TransferCertificateResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot.model.TransferCertificateResponse
      .builder()
      .optionallyWith(
        transferredCertificateArn.map(value =>
          CertificateArn.unwrap(value): java.lang.String
        )
      )(_.transferredCertificateArn)
      .build()
  }
  def asReadOnly: zio.aws.iot.model.TransferCertificateResponse.ReadOnly =
    zio.aws.iot.model.TransferCertificateResponse.wrap(buildAwsValue())
}
object TransferCertificateResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot.model.TransferCertificateResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot.model.TransferCertificateResponse =
      zio.aws.iot.model.TransferCertificateResponse(
        transferredCertificateArn.map(value => value)
      )
    def transferredCertificateArn: Option[CertificateArn]
    def getTransferredCertificateArn: ZIO[Any, AwsError, CertificateArn] =
      AwsError.unwrapOptionField(
        "transferredCertificateArn",
        transferredCertificateArn
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot.model.TransferCertificateResponse
  ) extends zio.aws.iot.model.TransferCertificateResponse.ReadOnly {
    override val transferredCertificateArn: Option[CertificateArn] = scala
      .Option(impl.transferredCertificateArn())
      .map(value => zio.aws.iot.model.primitives.CertificateArn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot.model.TransferCertificateResponse
  ): zio.aws.iot.model.TransferCertificateResponse.ReadOnly = new Wrapper(impl)
}
